This home page for kacypdf project

# To generate distribution package,
# python setup.py sdist bdist_wheel
# This will generate two dist package, source and build distribution
# To upload to pypi use twine
# twine upload dist/*